# Bravado Django Test Client

![https://docs.djangoproject.com/en/2.1/topics/testing/tools/#the-test-client](Django Test Client) compatible HTTP Client for ![https://github.com/Yelp/bravado](Bravado).

This allows your Django API and OpenAPI v2 (Swagger) specification files to be tested against each other in your unit tests. The aim being to quickly highlight any potential discrepancies between the specification and your actual API.